@@ -1,5 +1,5 @@
 CREATE TABLE memos (
-  id integer,
+  id integer PRIMARY KEY,
   content text
 );
 
@@ -7,7 +7,7 @@ INSERT INTO memos VALUES (1, 'PostgreSQL is a RDBMS.');
 INSERT INTO memos VALUES (2, 'Groonga is fast full text search engine.');
 INSERT INTO memos VALUES (3, 'PGroonga is a PostgreSQL extension that uses Groonga.');
 
-CREATE INDEX grnindex ON memos USING pgroonga (content);
+CREATE INDEX grnindex ON memos USING pgroonga (id, content);
 
 SET enable_seqscan = off;
 SET enable_indexscan = on;
